@@ -10,9 +10,7 @@ import os
 from datetime import datetime, timedelta
 
 from .base_test import BaseTest
-from newtools import CachedPep249Query, CachedAthenaQuery, BaseCachedQuery
-
-from newtools.optional_imports import CSVHandler
+from newtools import CachedPep249Query, CachedAthenaQuery, BaseCachedQuery, PandasDoggo
 
 
 class TestCachedQuery(BaseTest):
@@ -189,7 +187,7 @@ class TestCachedQuery(BaseTest):
                           params={"day_list": ['{0:%Y-%m-%d}'.format(day) for day in days]})
 
         # Get the output
-        output = CSVHandler().load_df(r, compression="gzip")
+        output = PandasDoggo().load_csv(r, compression="gzip")
 
         # Clear the cache again
         q.clear_cache(sql_file="athena_test.sql",
@@ -232,7 +230,7 @@ class TestCachedQuery(BaseTest):
                               "{day_list}": "(" + ",".join(["'{0:%Y-%m-%d}'".format(day) for day in days]) + ")"})
 
         # Get the output
-        output = CSVHandler().load_df(r, compression="gzip")
+        output = PandasDoggo().load_csv(r, compression="gzip")
 
         # check the results
         self.assertEqual(output.to_csv(index=False),
@@ -306,7 +304,7 @@ class TestCachedQuery(BaseTest):
                               "{day_list}": "(" + ",".join(["'{0:%Y-%m-%d}'".format(day) for day in days]) + ")"})
 
         # Get the output
-        output = CSVHandler().load_df(r, compression="gzip")
+        output = PandasDoggo().load_csv(r, compression="gzip")
 
         # check the results
         self.assertEqual(output.to_csv(index=False),
